@@ -36,9 +36,9 @@ static KHotKeys::ActionDataBase *findElement(
         ,KHotKeys::ActionDataGroup *root)
     {
     Q_ASSERT(root);
-    if (!root) return NULL;
+    if (!root) return nullptr;
 
-    KHotKeys::ActionDataBase *match = NULL;
+    KHotKeys::ActionDataBase *match = nullptr;
 
     Q_FOREACH( KHotKeys::ActionDataBase *element, root->children())
         {
@@ -664,7 +664,7 @@ bool KHotkeysModel::setData( const QModelIndex &index, const QVariant &value, in
                     : action->disable();
 
                 // If this is a group we have to inform the view that all our
-                // childs have changed. They are all disabled now
+                // children have changed. They are all disabled now
                 KHotKeys::ActionDataGroup *actionGroup = indexToActionDataGroup(index);
                 if (actionGroup && actionGroup->size())
                     {
